import { ulid } from "ulid";

import { Account } from "~entities/account.js";
import { Blog } from "~entities/blog.js";
import { generateKeyPair } from "./util/rsa.js";
import MercuryDataSource from "./index.js";

export const incorrectAccountType = new Error("wrong account type for function");

/** Create a local blog. Throws an error if the given account is not a local account. */
export async function createLocalBlog(account: Account, name: string) {
  if (account.host) throw incorrectAccountType;

  const keyPair = await generateKeyPair();

  const blog = new Blog();
  blog.id = ulid();
  blog.username = name;
  blog.host = account.host;
  blog.account = account;
  blog.publicKey = keyPair.publicKey;
  blog.privateKey = keyPair.privateKey;

  await MercuryDataSource.getRepository(Blog).save(blog);

  return blog;
}

export async function createRemoteBlog(account: Account, name: string, apId: string, publicKey: string) {
  if (!account.host) throw incorrectAccountType;

  const blog = new Blog();
  blog.id = ulid();
  blog.apId = apId;
  blog.username = name;
  blog.host = account.host;
  blog.account = account;
  blog.publicKey = publicKey;

  await MercuryDataSource.getRepository(Blog).save(blog);

  return blog;
}
